intelmq.bots.collectors.eset package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.collectors.eset package

## Submodules

## intelmq.bots.collectors.eset.collector module

`intelmq.bots.collectors.eset.collector.` `BOT`

  alias of `intelmq.bots.collectors.eset.collector.ESETCollectorBot`

class `intelmq.bots.collectors.eset.collector.` `ESETCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  `init`()
  `process`()

## Module contents